==> rbac-server-starter-2.2.1.2-Release-sources.jar: com/bizunited/platform/rbac/server/starter/configuration/RbacServerStarterAutoConfiguration.java <==
package com.bizunited.platform.rbac.server.starter.configuration;

import com.bizunited.platform.rbac.server.service.ButtonService;
import com.bizunited.platform.rbac.server.service.CompetenceService;
import com.bizunited.platform.rbac.server.service.RoleOrgMappingService;
import com.bizunited.platform.rbac.server.service.RolePositionMappingService;
import com.bizunited.platform.rbac.server.service.RoleService;
import com.bizunited.platform.rbac.server.service.RoleUserGroupMappingService;
import com.bizunited.platform.rbac.server.service.RoleUserMappingService;
import com.bizunited.platform.rbac.server.starter.service.internal.ButtonServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.CompetenceServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RoleOrgMappingServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RolePositionMappingServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RoleServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RoleUserGroupMappingServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RoleUserMappingServiceImpl;

import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.jpa.repository.config.EnableJpaRepositories;

/**
 * rbac服务实现的配置
 * @Author: Paul Chan
 * @Date: 2020-03-30 17:55
 */
@Configuration
@EntityScan(basePackages = "com.bizunited.platform.rbac.server.starter.entity")
@EnableJpaRepositories(basePackages = "com.bizunited.platform.rbac.server.starter.repository")
@ComponentScan(basePackages = {"com.bizunited.platform.rbac.server", "com.bizunited.platform.common"})
public class RbacServerStarterAutoConfiguration {

  @Bean(name="CompetenceService")
  @ConditionalOnMissingBean
  public CompetenceService getCompetenceService() {
    return new CompetenceServiceImpl();
  }
  @Bean(name="RoleService")
  @ConditionalOnMissingBean
  public RoleService getRoleService() {
    return new RoleServiceImpl();
  }
  @Bean(name="ButtonService")
  @ConditionalOnMissingBean
  public ButtonService getButtonService() {
    return new ButtonServiceImpl();
  }
  @Bean(name="RoleOrgMappingService")
  @ConditionalOnMissingBean
  public RoleOrgMappingService getRoleOrgMappingService() {
    return new RoleOrgMappingServiceImpl();
  }
  @Bean(name="RolePositionMappingService")
  @ConditionalOnMissingBean
  public RolePositionMappingService getRolePositionMappingService() {
    return new RolePositionMappingServiceImpl();
  }
  @Bean(name="RoleUserGroupMappingService")
  @ConditionalOnMissingBean
  public RoleUserGroupMappingService getRoleUserGroupMappingService() {
    return new RoleUserGroupMappingServiceImpl();
  }
  @Bean(name="RoleUserMappingService")
  @ConditionalOnMissingBean
  public RoleUserMappingService getRoleUserMappingService() {
    return new RoleUserMappingServiceImpl();
  }
}

==> rbac-server-starter-2.2.1.12-Release-sources.jar: com/bizunited/platform/rbac/server/starter/configuration/RbacServerStarterAutoConfiguration.java <==
package com.bizunited.platform.rbac.server.starter.configuration;

import com.bizunited.platform.rbac.server.service.ButtonService;
import com.bizunited.platform.rbac.server.service.CompetenceService;
import com.bizunited.platform.rbac.server.service.RoleOrgMappingService;
import com.bizunited.platform.rbac.server.service.RolePositionMappingService;
import com.bizunited.platform.rbac.server.service.RoleService;
import com.bizunited.platform.rbac.server.service.RoleUserGroupMappingService;
import com.bizunited.platform.rbac.server.service.RoleUserMappingService;
import com.bizunited.platform.rbac.server.starter.service.internal.ButtonServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.CompetenceServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RoleOrgMappingServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RolePositionMappingServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RoleServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RoleUserGroupMappingServiceImpl;
import com.bizunited.platform.rbac.server.starter.service.internal.RoleUserMappingServiceImpl;

import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.jpa.repository.config.EnableJpaRepositories;

/**
 * rbac服务实现的配置
 * @Author: Paul Chan
 * @Date: 2020-03-30 17:55
 */
@Configuration
@EntityScan(basePackages = "com.bizunited.platform.rbac.server.starter.entity")
@EnableJpaRepositories(basePackages = "com.bizunited.platform.rbac.server.starter.repository")
@ComponentScan(basePackages = {"com.bizunited.platform.rbac", "com.bizunited.platform.common"})
public class RbacServerStarterAutoConfiguration {

  @Bean(name="CompetenceService")
  @ConditionalOnMissingBean
  public CompetenceService getCompetenceService() {
    return new CompetenceServiceImpl();
  }
  @Bean(name="RoleService")
  @ConditionalOnMissingBean
  public RoleService getRoleService() {
    return new RoleServiceImpl();
  }
  @Bean(name="ButtonService")
  @ConditionalOnMissingBean
  public ButtonService getButtonService() {
    return new ButtonServiceImpl();
  }
  @Bean(name="RoleOrgMappingService")
  @ConditionalOnMissingBean
  public RoleOrgMappingService getRoleOrgMappingService() {
    return new RoleOrgMappingServiceImpl();
  }
  @Bean(name="RolePositionMappingService")
  @ConditionalOnMissingBean
  public RolePositionMappingService getRolePositionMappingService() {
    return new RolePositionMappingServiceImpl();
  }
  @Bean(name="RoleUserGroupMappingService")
  @ConditionalOnMissingBean
  public RoleUserGroupMappingService getRoleUserGroupMappingService() {
    return new RoleUserGroupMappingServiceImpl();
  }
  @Bean(name="RoleUserMappingService")
  @ConditionalOnMissingBean
  public RoleUserMappingService getRoleUserMappingService() {
    return new RoleUserMappingServiceImpl();
  }
}
